aboutsummaryrefslogtreecommitdiff
path: root/src/ejabberd_auth.erl
diff options
context:
space:
mode:
authorMickaël Rémond <mickael.remond@process-one.net>2007-12-24 11:41:41 +0000
committerMickaël Rémond <mickael.remond@process-one.net>2007-12-24 11:41:41 +0000
commit56fe3579bb991a9efa97fd9ed4b8dd3632e36636 (patch)
treebcf3569988fc3c7067379aaf017a5e6bc0481e03 /src/ejabberd_auth.erl
parentpubsub: remove useless get_roster_info call (diff)
* Applied copyright update patch 1.
SVN Revision: 1110
Diffstat (limited to 'src/ejabberd_auth.erl')
-rw-r--r--src/ejabberd_auth.erl28
1 files changed, 22 insertions, 6 deletions
diff --git a/src/ejabberd_auth.erl b/src/ejabberd_auth.erl
index 37145f5d9..d2f799672 100644
--- a/src/ejabberd_auth.erl
+++ b/src/ejabberd_auth.erl
@@ -1,17 +1,33 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_auth.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Authentification
-%%% Created : 23 Nov 2002 by Alexey Shchepin <alexey@sevcom.net>
-%%% Updated : 23 Feb 2006 by Mickael Remond <mremond@process-one.net>
-%%% for anonymous login support
-%%% Id : $Id$
+%%% Created : 23 Nov 2002 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
%% TODO: Use the functions in ejabberd auth to add and remove users.
-module(ejabberd_auth).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
%% External exports
-export([start/0,
@@ -1,17 +1,33 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_auth.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Authentification